@@ -26,8 +26,8 @@ def create_customer():
             payment_provider='stripe',
             provider_customer_id='cus_12345',
             sync_with_provider=True,
-            vat_rate=12.5,
-            document_locale="fr"
+            document_locale="fr",
+            provider_payment_methods=["card", "sepa_debit"],
         ),
         metadata=metadata_list
     )
@@ -56,7 +56,6 @@ def test_valid_create_customers_request(httpx_mock: HTTPXMock):
     assert response.billing_configuration.payment_provider == 'stripe'
     assert response.billing_configuration.provider_customer_id == 'cus_12345'
     assert response.billing_configuration.sync_with_provider == True
-    assert response.billing_configuration.vat_rate == 12.5
     assert response.billing_configuration.document_locale == "fr"
     assert response.metadata.__root__[0].key == 'key'
     assert response.metadata.__root__[0].value == 'value'
@@ -84,6 +83,8 @@ def test_valid_current_usage(httpx_mock: HTTPXMock):
     assert response.from_datetime == '2022-07-01T00:00:00Z'
     assert len(response.charges_usage) == 1
     assert response.charges_usage[0].units == 1.0
+    assert len(response.charges_usage[0].groups) == 1
+    assert response.charges_usage[0].groups[0].key == 'google'
 
 
 def test_invalid_current_usage(httpx_mock: HTTPXMock):
